@@ -191,12 +191,12 @@ print.suda2 <- function(x, ...) {
   tab <- table(cut(x$disScore, breaks = c(-1, SEQ, Inf)))
   res <- data.frame(interval = DISSudaScore, "number of records" = as.numeric(tab))
   colnames(res) <- c("Interval", "Number of records")
-  cat("\nDis suda scores table: \n")
-  cat("- - - - - - - - - - - \n")
+  message("\nDis suda scores table: \n")
+  message("- - - - - - - - - - - \n")
   print(res)
-  cat("- - - - - - - - - - - \n")
-  cat("Attribute contribution:\n")
-  cat("- - - - - - - - - - - \n")
+  message("- - - - - - - - - - - \n")
+  message("Attribute contribution:\n")
+  message("- - - - - - - - - - - \n")
   print(x$attribute_contributions)
-  cat("- - - - - - - - - - - \n")
+  message("- - - - - - - - - - - \n")
 }
